<?php

namespace AdGrid;

// Include the AdminSettingsFields class
require_once plugin_dir_path(__FILE__) . '/AdminSettingsFields.php';

class AdGrid {

    public function __construct() {
        // Hook to add the external script to the wp_head action
        add_action('wp_head', array($this, 'add_custom_code'));

        // Hook to add the settings page to the admin menu
        add_action('admin_menu', array($this, 'add_settings_page'));

        // Instantiate AdminSettingsFields class
        new AdminSettingsFields();
    }

    public function add_custom_code() {
        // Check if the script or custom code has already been added
        static $added = false;

        if (!$added) {
            $this->enqueue_header_external_script();
            $added = true;
        }

        // Check if the user has selected to include tags or categories
        // Will be an seperate function needed for the tags and categories 
        $include_tags = get_option('adgrid_include_tags');
        $include_categories = get_option('adgrid_include_categories');
        // New code to include post ID and post type
        // Next two line may not be needed anymore here, just need to check
        $include_post_id = get_option('adgrid_include_post_id');
        $include_post_type = get_option('adgrid_include_post_type');

        if (!empty($include_tags) || !empty($include_categories)) {
            $this->enqueue_taxonomy_script($include_tags, $include_categories);
        }

        // New functions for post ID and post type
        $this->enqueue_post_id_script();
        $this->enqueue_post_type_script();
        
    }

    public function enqueue_header_external_script() {
        // Get the saved script URL from the options
        $script_url = get_option('adgrid_script_url');

        if (!empty($script_url)) {
            ?>
            <script src="<?php echo esc_url($script_url); ?>"></script>
            <?php
        }
    }


    public function enqueue_taxonomy_script($include_tags, $include_categories) {
        // Get the current post ID
        $post_id = get_the_ID();

        if (!empty($post_id)) {
            // Get the tags and/or categories from the specific post
            $terms = array();

            if (!empty($include_tags)) {
                $tags = get_the_tags($post_id);
                if (!empty($tags)) {
                    $terms['tags'] = wp_list_pluck($tags, 'slug');
                }
            }

            if ($include_categories) {
                $categories = get_the_category($post_id);
                if (!empty($categories)) {
                    $terms['categories'] = wp_list_pluck($categories, 'slug');
                }
            }

            if (!empty($terms)) {
                ?>
                <script>
                    var adgridConfig = adgridConfig || {};
                    adgridConfig.kvp = adgridConfig.kvp || {};

                    <?php if (!empty($terms['tags'])) : ?>
                        adgridConfig.kvp.tags = <?php echo json_encode($terms['tags']); ?>;
                    <?php endif; ?>

                    <?php if (!empty($terms['categories'])) : ?>
                        adgridConfig.kvp.categories = <?php echo json_encode($terms['categories']); ?>;
                    <?php endif; ?>
                </script>
                <?php
            }
        }
    }

    private function enqueue_post_id_script() {
        $include_post_id = get_option('adgrid_include_post_id');

        if (!empty($include_post_id)) {
            $queried_object_id = get_queried_object_id();

            if (!empty($queried_object_id)) {
                ?>
                <script>
                    var adgridConfig = adgridConfig || {};
                    adgridConfig.kvp = adgridConfig.kvp || {};
                    adgridConfig.kvp.post_id = <?php echo json_encode($queried_object_id); ?>;
                </script>
                <?php
            }
        }
    }

    private function enqueue_post_type_script() {
        $include_post_type = get_option('adgrid_include_post_type');

        if (!empty($include_post_type)) {
            $queried_object = get_queried_object();

            if (!empty($queried_object) && property_exists($queried_object, 'post_type')) {
                $post_type = $queried_object->post_type;
                ?>
                <script>
                    var adgridConfig = adgridConfig || {};
                    adgridConfig.kvp = adgridConfig.kvp || {};
                    adgridConfig.kvp.post_type = <?php echo json_encode($post_type); ?>;
                </script>
                <?php
            }
        }
    }

    public function add_settings_page() {
        // Check if the settings page has already been added
        if (!current_user_can('manage_options')) {
            return;
        }

        if (!isset($GLOBALS['adgrid_settings_page_added'])) {
            $GLOBALS['adgrid_settings_page_added'] = true;
            add_options_page('AdGrid Settings', 'AdGrid', 'manage_options', 'adgrid-settings', array($this, 'settings_page_content'));
        }
    }

    public function settings_page_content() {
        ?>
        <div class="wrap">
            <h2>AdGrid Settings</h2>
            <form method="post" action="options.php">
                <?php
                settings_fields('adgrid_settings_group');
                do_settings_sections('adgrid-settings');
                submit_button();
                ?>
            </form>
        </div>
        <?php
    }
}

// Initialize the plugin
new AdGrid();
