<?php

namespace AdGrid;

class AdminSettingsFields {

    public function __construct() {
        // Hook to add the settings fields to the admin page
        add_action('admin_init', array($this, 'register_settings_fields'));
    }

    public function register_settings_fields() {
        register_setting('adgrid_settings_group', 'adgrid_script_url', 'esc_url');
        register_setting('adgrid_settings_group', 'adgrid_include_tags', 'intval');
        register_setting('adgrid_settings_group', 'adgrid_include_categories', 'intval');
        register_setting('adgrid_settings_group', 'adgrid_include_post_id', 'intval');
        register_setting('adgrid_settings_group', 'adgrid_include_post_type', 'intval');


        add_settings_section('adgrid_main_section', 'Script Settings', array($this, 'section_callback'), 'adgrid-settings');
        add_settings_field('adgrid_script_url', 'AdGrid Header Code(V5)', array($this, 'url_field_callback'), 'adgrid-settings', 'adgrid_main_section');
        add_settings_field('adgrid_include_tags', 'Include Tags', array($this, 'include_tags_field_callback'), 'adgrid-settings', 'adgrid_main_section');
        add_settings_field('adgrid_include_categories', 'Include Categories', array($this, 'include_categories_field_callback'), 'adgrid-settings', 'adgrid_main_section');
        add_settings_field('adgrid_include_post_id', 'Include Post ID', array($this, 'include_post_id_field_callback'), 'adgrid-settings', 'adgrid_main_section');
        add_settings_field('adgrid_include_post_type', 'Include Post Type', array($this, 'include_post_type_field_callback'), 'adgrid-settings', 'adgrid_main_section');
    }

    public function section_callback() {
        echo '<p>Enter the URL for the external Adgrid JavaScript file and configure additional settings.</p>';
    }

    public function url_field_callback() {
        $script_url = get_option('adgrid_script_url');
        ?>
        <textarea type="text" name="adgrid_script_url" value="<?php echo esc_url($script_url); ?>" class="large-text code" rows="7"><?php echo esc_textarea($script_url); ?></textarea>
        <p class="description">Example: https://console.adgrid.io/adgrid-build/adgrid-io/revenue-grid.js</p>
        <?php
    }

    public function include_tags_field_callback() {
        $include_tags = get_option('adgrid_include_tags');
        ?>
        <label>
            <input type="checkbox" name="adgrid_include_tags" value="1" <?php checked($include_tags, 1); ?>>
            Include tags in adgridConfig variable
        </label>
        <?php
    }

    public function include_categories_field_callback() {
        $include_categories = get_option('adgrid_include_categories');
        ?>
        <label>
            <input type="checkbox" name="adgrid_include_categories" value="1" <?php checked($include_categories, 1); ?>>
            Include categories in adgridConfig variable
        </label>
        <?php
    }

    public function include_post_id_field_callback() {
        $include_post_id = get_option('adgrid_include_post_id');
        ?>
        <label>
            <input type="checkbox" name="adgrid_include_post_id" value="1" <?php checked($include_post_id, 1); ?>>
            Include post ID in adgridConfig variable
        </label>
        <?php
    }
    
    public function include_post_type_field_callback() {
        $include_post_type = get_option('adgrid_include_post_type');
        ?>
        <label>
            <input type="checkbox" name="adgrid_include_post_type" value="1" <?php checked($include_post_type, 1); ?>>
            Include post type in adgridConfig variable
        </label>
        <?php
    }
    
}
